==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/bg/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Този потребител може да се логне',
    'activated_disabled_help_text' => 'Не можете да редактирате статуса на активация на собствения си профил.',
    'assets_user'       => 'Активи предадени на :name',
    'bulk_update_warn'	=> 'На път сте да редактирате свойствата на :user_count потребители. Моля обърнете внимание, че не можете да променяте собствените си атрибути използвайки този формуляр и трябва да нанесете промени към собствения си потребителски профил индивидуално.',
    'bulk_update_help'	=> 'Този формуляр ви позволява да обновявате няколко потребителски профила едновременно. Попълнете единствено полетата, които желаете да промените. Всички празни полета няма да бъдат променени.',
    'current_assets'    => 'Активи, отписани към този потребител в момента',
    'clone'             => 'Копиране на потребител',
    'contact_user'      => 'Връзка :name',
    'edit'              => 'Редактиране на потребител',
    'filetype_info'     => 'Позволените типове файлове са png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, и rar.',
    'history_user'      => 'История за :name',
	'info'				=> 'Информация',
    'restore_user'		=> 'Кликнете тук, за да ги възстановите.',
    'last_login'        => 'Последен достъп до системата',
    'ldap_config_text'  => 'LDAP конфигурационните настройки могат да бъдат намерени в  Admin > Settings. Избраното (по изобр) местоположение ще бъде настроено за всички въведени потребители.',
    'print_assigned'    => 'Печат на всички отдадени',
    'software_user'     => 'Софтуерни продукти, изписани на :name',
    'send_email_help'   => 'Трябва да предоставите е-майл адрес за този потребител за да му се изпратят името и паролата. Изпращането на име и парола може да стане при създаването на потребителя. Паролите се съхраняват криптирани и не могат да се възстановят.',
    'view_user'         => 'Преглед на потребител :name',
    'usercsv'           => 'CSV файл',
    'two_factor_admin_optin_help' => 'Текущите настройки на администратор позволяват избирателно прилагане на двуфакторова автентификация. ',
    'two_factor_enrolled' => '2FA устройство записано',
    'two_factor_active'   => '2FA Активно',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/bg/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Този потребител може да се логне',
    'activated_disabled_help_text' => 'Не можете да редактирате статуса на активация на собствения си профил.',
    'assets_user'       => 'Активи предадени на :name',
    'bulk_update_warn'	=> 'На път сте да редактирате свойствата на :user_count потребители. Моля обърнете внимание, че не можете да променяте собствените си атрибути използвайки този формуляр и трябва да нанесете промени към собствения си потребителски профил индивидуално.',
    'bulk_update_help'	=> 'Този формуляр ви позволява да обновявате няколко потребителски профила едновременно. Попълнете единствено полетата, които желаете да промените. Всички празни полета няма да бъдат променени.',
    'current_assets'    => 'Активи, отписани към този потребител в момента',
    'clone'             => 'Копиране на потребител',
    'contact_user'      => 'Връзка :name',
    'edit'              => 'Редактиране на потребител',
    'filetype_info'     => 'Позволените типове файлове са png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, и rar.',
    'history_user'      => 'История за :name',
    'info'				=> 'Информация',
    'restore_user'		=> 'Кликнете тук, за да ги възстановите.',
    'last_login'        => 'Последен достъп до системата',
    'ldap_config_text'  => 'LDAP конфигурационните настройки могат да бъдат намерени в  Admin > Settings. Избраното (по изобр) местоположение ще бъде настроено за всички въведени потребители.',
    'print_assigned'    => 'Печат на всички отдадени',
    'software_user'     => 'Софтуерни продукти, изписани на :name',
    'send_email_help'   => 'Трябва да предоставите е-майл адрес за този потребител за да му се изпратят името и паролата. Изпращането на име и парола може да стане при създаването на потребителя. Паролите се съхраняват криптирани и не могат да се възстановят.',
    'view_user'         => 'Преглед на потребител :name',
    'usercsv'           => 'CSV файл',
    'two_factor_admin_optin_help' => 'Текущите настройки на администратор позволяват избирателно прилагане на двуфакторова автентификация. ',
    'two_factor_enrolled' => '2FA устройство записано',
    'two_factor_active'   => '2FA Активно',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
